@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Ogre::MovableObject;
-our @ISA = qw(Ogre::MovableObject);
+our @ISA = qw(Ogre::MovableObject);   # Ogre::Resource::Listener
 
 
 1;
